==> roco-oil-card-settle-api-0.0.2-20200227.092854-10-sources.jar: com/roco/settle/api/entity/SettleCapitalAccount.java <==
package com.roco.settle.api.entity;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.roco.settle.api.enums.IsEnum;
import com.roco.settle.api.enums.StatusEnum;
import com.roco.settle.api.util.DateUtil;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Transient;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * <dl>
 * <dd>Description: </dd>
 * <dd>Company: 大城若谷信息技术有限公司</dd>
 * <dd>@date：2020/2/5 10:16</dd>
 * <dd>@author：zhanghs</dd>
 * </dl>
 */
@Table(name = "settle_capital_account")
@Getter
@Setter
@ToString
public class SettleCapitalAccount implements Serializable {

    @Id
    private Long id;

    /**
     * 账户编码
     */
    private String accountCode;

    /**
     * 机构编码
     */
    private String enterpriseCode;

    /**
     * 机构简称
     */
    private String enterpriseSimpleName;

    /**
     * 机构简称拼音
     */
    private String enterpriseNamePinyin;

    /**
     * 机构简称首字母
     */
    private String enterpriseNameFirtPinyin;

    /**
     * 人保机构号
     */
    private String piccOrgCode;

    /**
     * 业务主体编码
     */
    private String bizSubjectCode;

    @Transient
    private String bizSubjectSimpleName;

    /**
     * 存入总金额
     */
    private BigDecimal totalAmount;

    /**
     * 账户余额
     */
    private BigDecimal canAmount;

    /**
     * 已结算总额
     */
    private BigDecimal settledAmount;

    /**
     * 未结算总额
     */
    private BigDecimal unsettledAmount;

    /**
     * 未结算订单数
     */
    private Integer unsettledOrderCnt;

    /**
     * 已结算订单数
     */
    private Integer settledOrderCnt;

    /**
     * 存款次数
     */
    private Integer depositCnt;

    /**
     * 结算次数
     */
    private Integer settledCnt;

    /**
     * 业务主体是否垫资
     */
    @Column(name = "debt")
    private IsEnum debt;

    /**
     * 垫资金额
     */
    private BigDecimal debtAmount;

    /**
     * 账户状态
     */
    @Column(name = "status")
    private StatusEnum status;

    /**
     * 版本号
     */
    private Integer revision;


    /**
     * 创建人id
     */
    private Long createUser;

    /**
     * 创建人姓名
     */
    private String createUsername;

    /**
     * 创建日期
     */
    @JsonFormat(pattern = DateUtil.YYYY_MM_DD, timezone = DateUtil.TIME_ZONE)
    private LocalDate createDate;

    /**
     * 创建时间
     */
    @JsonFormat(pattern = DateUtil.YYYY_MM_DD_HH_MM_SS, timezone = DateUtil.TIME_ZONE)
    private LocalDateTime createTime;

    @JsonFormat(pattern = DateUtil.YYYY_MM_DD_HH_MM_SS, timezone = DateUtil.TIME_ZONE)
    private LocalDateTime updateTime;

    /**
     * 更新人id
     */
    private Long updateUser;

    /**
     * 更新人姓名
     */
    private String updateUsername;

    public void setInit(BigDecimal totalAmount,BigDecimal canAmount,BigDecimal settledAmount,
                        BigDecimal unsettledAmount,Integer unsettledOrderCnt,Integer settledOrderCnt,Integer depositCnt,
                        Integer settledCnt,IsEnum debt,BigDecimal debtAmount,Integer revision){
        this.setTotalAmount(totalAmount);
        this.setCanAmount(canAmount);
        this.setSettledAmount(settledAmount);
        this.setUnsettledAmount(unsettledAmount);
        this.setUnsettledOrderCnt(unsettledOrderCnt);
        this.setSettledOrderCnt(settledOrderCnt);
        this.setDepositCnt(depositCnt);
        this.setSettledCnt(settledCnt);
        this.setDebt(debt);
        this.setDebtAmount(debtAmount);
        this.setRevision(revision);
    }

}

==> roco-oil-card-settle-api-1.3.4.20200503.023013-2-sources.jar: com/roco/settle/api/entity/SettleCapitalAccount.java <==
package com.roco.settle.api.entity;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.roco.settle.api.enums.IsEnum;
import com.roco.settle.api.enums.StatusEnum;
import com.roco.settle.api.util.DateUtil;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;

import javax.persistence.Column;
import javax.persistence.Id;
import javax.persistence.Table;
import javax.persistence.Transient;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * <dl>
 * <dd>Description: </dd>
 * <dd>Company: 大城若谷信息技术有限公司</dd>
 * <dd>@date：2020/2/5 10:16</dd>
 * <dd>@author：zhanghs</dd>
 * </dl>
 */
@Table(name = "settle_capital_account")
@Getter
@Setter
@ToString
public class SettleCapitalAccount implements Serializable {

    @Id
    private Long id;

    /**
     * 账户编码
     */
    private String accountCode;

    /**
     * 机构编码
     */
    private String enterpriseCode;

    /**
     * 机构简称
     */
    private String enterpriseSimpleName;

    /**
     * 机构简称拼音
     */
    private String enterpriseNamePinyin;

    /**
     * 机构简称首字母
     */
    private String enterpriseNameFirtPinyin;

    /**
     * 人保机构号
     */
    private String piccOrgCode;

    /**
     * 业务主体编码
     */
    private String bizSubjectCode;

    @Transient
    private String bizSubjectSimpleName;

    /**
     * 存入总金额
     */
    private BigDecimal totalAmount;

    /**
     * 业务发生额
     */
    private BigDecimal useAmount;

    /**
     * 账户余额
     */
    private BigDecimal canAmount;

    /**
     * 已结算总额
     */
    private BigDecimal settledAmount;

    /**
     * 未结算总额
     */
    private BigDecimal unsettledAmount;

    /**
     * 未结算订单数
     */
    private Integer unsettledOrderCnt;

    /**
     * 已结算订单数
     */
    private Integer settledOrderCnt;

    /**
     * 存款次数
     */
    private Integer depositCnt;

    /**
     * 结算次数
     */
    private Integer settledCnt;


    /**
     * 油卡结算次数
     */
    private Integer oilSettledCnt;

    /**
     * 油卡已结算金额
     */
    private BigDecimal oilSettledAmount;


    /**
     * 油卡已发放金额
     */
    private BigDecimal oilRechargeAmount;


    /**
     * 油卡发生费用额
     */
    private BigDecimal oilUseAmount;


    /**
     * 油卡上次结算日期
     */
    @JsonFormat(pattern = DateUtil.YYYY_MM_DD, timezone = DateUtil.TIME_ZONE)
    private LocalDate oilSettledLastDate;


    /**
     * 业务主体是否垫资
     */
    @Column(name = "debt")
    private IsEnum debt;

    /**
     * 垫资金额
     */
    private BigDecimal debtAmount;

    /**
     * 账户状态
     */
    @Column(name = "status")
    private StatusEnum status;

    /**
     * 版本号
     */
    private Integer revision;


    /**
     * 创建人id
     */
    private Long createUser;

    /**
     * 创建人姓名
     */
    private String createUsername;

    /**
     * 创建日期
     */
    @JsonFormat(pattern = DateUtil.YYYY_MM_DD, timezone = DateUtil.TIME_ZONE)
    private LocalDate createDate;

    /**
     * 创建时间
     */
    @JsonFormat(pattern = DateUtil.YYYY_MM_DD_HH_MM_SS, timezone = DateUtil.TIME_ZONE)
    private LocalDateTime createTime;

    @JsonFormat(pattern = DateUtil.YYYY_MM_DD_HH_MM_SS, timezone = DateUtil.TIME_ZONE)
    private LocalDateTime updateTime;

    /**
     * 更新人id
     */
    private Long updateUser;

    /**
     * 更新人姓名
     */
    private String updateUsername;


    /**
     * 结算可用金额 =  打款总金额 - 已结算金额
     * @return
     */
    public BigDecimal getAvailableSettleAmount() {
        return totalAmount.subtract(settledAmount);
    }


    /**
     * 油卡未结算金额  = 油卡发生费用额 -  已结算金额
     * @return
     */
    public BigDecimal getOilUnsettledAmount() {
        return oilUseAmount.subtract(oilSettledAmount);
    }


    public void setInit(BigDecimal totalAmount,BigDecimal canAmount,BigDecimal settledAmount,
                        BigDecimal unsettledAmount,Integer unsettledOrderCnt,Integer settledOrderCnt,Integer depositCnt,
                        Integer settledCnt,IsEnum debt,BigDecimal debtAmount,Integer revision){
        this.setTotalAmount(totalAmount);
        this.setCanAmount(canAmount);
        this.setSettledAmount(settledAmount);
        this.setUnsettledAmount(unsettledAmount);
        this.setUnsettledOrderCnt(unsettledOrderCnt);
        this.setSettledOrderCnt(settledOrderCnt);
        this.setDepositCnt(depositCnt);
        this.setSettledCnt(settledCnt);
        this.setDebt(debt);
        this.setDebtAmount(debtAmount);
        this.setRevision(revision);
    }

}
